@@ -52,7 +52,7 @@
 #include "gedit-enum-types.h"
 #include "gedittextregion.h"
 
-#ifdef G_OS_WIN32
+#ifndef ENABLE_GVFS_METADATA
 #include "gedit-metadata-manager.h"
 #else
 #define METADATA_QUERY "metadata::*"
@@ -745,7 +745,7 @@ on_uri_changed (GeditDocument *doc,
 		GParamSpec    *pspec,
 		gpointer       useless)
 {
-#ifndef G_OS_WIN32
+#ifdef ENABLE_GVFS_METADATA
 	GFile *location;
 
 	location = gedit_document_get_location (doc);
@@ -1127,18 +1127,20 @@ gedit_document_get_mime_type (GeditDocument *doc)
 }
 
 /* Note: do not emit the notify::read-only signal */
-static void
+static gboolean
 set_readonly (GeditDocument *doc,
 	      gboolean       readonly)
 {
 	gedit_debug (DEBUG_DOCUMENT);
-	
+
 	readonly = (readonly != FALSE);
 
 	if (doc->priv->readonly == readonly) 
-		return;
+		return FALSE;
 
 	doc->priv->readonly = readonly;
+
+	return TRUE;
 }
 
 /**
@@ -1156,9 +1158,10 @@ _gedit_document_set_readonly (GeditDocument *doc,
 
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
-	set_readonly (doc, readonly);
-
-	g_object_notify (G_OBJECT (doc), "read-only");
+	if (set_readonly (doc, readonly))
+	{
+		g_object_notify (G_OBJECT (doc), "read-only");
+	}
 }
 
 gboolean
@@ -1174,7 +1177,6 @@ _gedit_document_check_externally_modified (GeditDocument *doc)
 {
 	GFile *gfile;
 	GFileInfo *info;
-	GTimeVal timeval;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
 
@@ -1185,23 +1187,39 @@ _gedit_document_check_externally_modified (GeditDocument *doc)
 
 	gfile = g_file_new_for_uri (doc->priv->uri);
 	info = g_file_query_info (gfile,
-				  G_FILE_ATTRIBUTE_TIME_MODIFIED,
+				  G_FILE_ATTRIBUTE_TIME_MODIFIED "," \
+				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
 				  G_FILE_QUERY_INFO_NONE,
 				  NULL, NULL);
 	g_object_unref (gfile);
 
-	if (info == NULL ||
-	    !g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
+	if (info != NULL)
 	{
-		return FALSE;
+		/* While at it also check if permissions changed */
+		if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE))
+		{
+			gboolean read_only;
+
+			read_only = !g_file_info_get_attribute_boolean (info,
+									G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+
+			_gedit_document_set_readonly (doc, read_only);
+		}
+
+		if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
+		{
+			GTimeVal timeval;
+
+			g_file_info_get_modification_time (info, &timeval);
+			g_object_unref (info);
+	
+			return (timeval.tv_sec > doc->priv->mtime.tv_sec) ||
+			       (timeval.tv_sec == doc->priv->mtime.tv_sec && 
+			       timeval.tv_usec > doc->priv->mtime.tv_usec);
+		}
 	}
 
-	g_file_info_get_modification_time (info, &timeval);
-	g_object_unref (info);
-	
-	return (timeval.tv_sec > doc->priv->mtime.tv_sec) ||
-	       (timeval.tv_sec == doc->priv->mtime.tv_sec && 
-	       timeval.tv_usec > doc->priv->mtime.tv_usec);
+	return FALSE;
 }
 
 static void
@@ -2553,7 +2571,7 @@ _gedit_document_create_mount_operation (GeditDocument *doc)
 						           doc->priv->mount_operation_userdata);
 }
 
-#ifdef G_OS_WIN32
+#ifndef ENABLE_GVFS_METADATA
 gchar *
 gedit_document_get_metadata (GeditDocument *doc,
 			     const gchar   *key)
@@ -2563,8 +2581,10 @@ gedit_document_get_metadata (GeditDocument *doc,
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 
-	if (doc->priv->uri != NULL)
+	if (!gedit_document_is_untitled (doc))
+	{
 		value = gedit_metadata_manager_get (doc->priv->uri, key);
+	}
 
 	return value;
 }
@@ -2581,6 +2601,12 @@ gedit_document_set_metadata (GeditDocument *doc,
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 	g_return_if_fail (first_key != NULL);
 
+	if (gedit_document_is_untitled (doc))
+	{
+		/* Can't set metadata for untitled documents */
+		return;
+	}
+
 	va_start (var_args, first_key);
 
 	for (key = first_key; key; key = va_arg (var_args, const gchar *))
