@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin.h 6635 2008-11-29 20:57:47Z pborelli $
+ * $Id$
  */
 
 #ifndef __GEDIT_PLUGIN_H__
@@ -100,6 +100,9 @@ struct _GeditPluginClass
  */
 GType 		 gedit_plugin_get_type 		(void) G_GNUC_CONST;
 
+gchar 		*gedit_plugin_get_install_dir	(GeditPlugin *plugin);
+gchar 		*gedit_plugin_get_data_dir	(GeditPlugin *plugin);
+
 void 		 gedit_plugin_activate		(GeditPlugin *plugin,
 						 GeditWindow *window);
 void 		 gedit_plugin_deactivate	(GeditPlugin *plugin,
